from email import utils as emailutils
import time


RFC2822_FORMAT = '%a, %d %b %Y %T %z'


def get_epoch_for_datetime(datetime):
    """ Given a datetime-like object, calculates the number of seconds that have elapsed since the Unix epoch. """
    rfc2822_formatted_date = datetime.strftime(RFC2822_FORMAT)
    time_tuple = emailutils.parsedate(rfc2822_formatted_date)
    return time.mktime(time_tuple)


def get_epoch_for_datetime_tz(datetime):
    """ Given a timezone aware datetime-like object, calculates the number of seconds that have elapsed since the Unix epoch. """
    rfc2822_formatted_date = datetime.strftime(RFC2822_FORMAT)
    time_tuple = emailutils.parsedate_tz(rfc2822_formatted_date)
    return emailutils.mktime_tz(time_tuple)



#!/usr/bin/python
from setuptools import setup, find_packages

setup(
    name='gtfe',
    packages=find_packages(),
    version='1.0.5',
    description='Get the number of seconds since the Unix epoch for a given datetime.',
    author='Matthew de Verteuil, Jason Peddle, Liav Koren',
    author_email='onceuponajooks@gmail.com',
    url='https://github.com/mverteuil/gtfe',
    keywords='epoch datetime time timezone',
    license='LICENSE',
    long_description=open('README', 'r').read(),
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Internet'
    ],
)
